## Preparation


### Environment variables

* `env`
* `gcp_project`
* `pubsub_topic_error`
* `pubsub_topic_email_send`
* `pubsub_topic_slack_send`
* `bigquery_dataset_error`
* `bigquery_table_error`
* `email_sender_error`
* `email_recipients_error`
* `slack_channels_error`